@@ -16,7 +16,7 @@
 */
 
 #include "customtoolsplugin.h"
-#include "helper_p.h"
+
 #include "customtoolsviewinterface.h"
 #include "customtoolswidgetng.h"
 #include "customtools/customtoolspluginmanager.h"
@@ -43,11 +43,10 @@ CustomToolsWidgetNg::CustomToolsWidgetNg(KActionCollection *ac, QWidget *parent)
     : QWidget(parent),
       d(new PimCommon::CustomToolsWidgetNgPrivate)
 {
-    QHBoxLayout *lay = new QHBoxLayout;
+    QHBoxLayout *lay = new QHBoxLayout(this);
     d->mStackedWidget = new QStackedWidget;
     d->mStackedWidget->setObjectName(QStringLiteral("stackedwidget"));
     lay->addWidget(d->mStackedWidget);
-    setLayout(lay);
     initializeView(ac);
     hide();
 }
